TokenKind enum
Values
- openingSquareBracket → const TokenKind
- closingSquareBracket → const TokenKind
- colon → const TokenKind
- quote → const TokenKind
- issueText → const TokenKind
- tilde → const TokenKind
- number → const TokenKind
- semicolon → const TokenKind
- openingCurlyBrace → const TokenKind
- closingCurlyBrace → const TokenKind
- comma → const TokenKind
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited