TokenIterator class
- Implemented types
- Available extensions
Constructors
-
TokenIterator(List<
Token> tokens)
Properties
- current → dynamic
-
The current element.
no setteroverride
- cursor ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
toJSIterator
→ JSIterator<
T> -
Available on Iterator<
A JSIterator wrapper that proxies to the Dart iterator API.T> , provided by the IteratorToJSIterator extensionno setter -
tokens
→ List<
Token> -
final
Methods
-
hasNext(
) → bool -
moveNext(
) → bool -
Advances the iterator to the next element of the iteration.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited